@@ -6,11 +6,24 @@ import json
 
 import logging
 logger = logging.getLogger(__name__)
-
+logger.setLevel(logging.INFO)
 
 class Server:
-    def __init__(self, port=13254):
-        logger.setLevel(logging.INFO)
+    """
+    Represents a winerp Server.
+    This class is used as the central communication center for all connected clients.
+    All requests and responses pass through the server
+
+    If the library is installed using PyPi, you can also use terminal to start server using `winerp --port 1234`
+    Parameters
+    -----------
+    port: Optional[:class:`int`]
+        The port on which the server is running. Defaults to 13254.
+    """
+    def __init__(
+        self,
+        port: int = 13254
+    ):
         self.websocket = WebsocketServer(host='127.0.0.1', port=port)
         self.websocket.set_fn_new_client(self.__on_client_connect)
         self.websocket.set_fn_message_received(self.__on_message)
@@ -19,7 +32,14 @@ class Server:
         self.active_clients = {}
         self.pending_verification = {}
         self.on_hold_connections = {}
-        
+    
+    @property
+    def client_count(self) -> int:
+        '''
+        :class:`int`: Returns the number of connected clients
+        '''
+        return len(self.active_clients)
+
     def __on_client_connect(self, client, server):
         logger.info("Client connected with id %s" % client['address'][1])
         self.pending_verification[client["address"][1]] = client
@@ -112,6 +132,16 @@ class Server:
 
         if msg.type.ping:
             logger.debug("Received Ping Message from client %s" % client['address'][1])
+            payload.type = Payloads.ping
+            if (msg.destination is not None and msg.destination in self.active_clients) or msg.destination is None:
+                payload.data = {"success": True}
+            else:
+                payload.data = {"success": False}
+                
+            self.__send_message(
+                client,
+                payload
+            )
 
         if msg.type.request:
             logger.debug("Received Request Message from client %s" % client['address'][1])
@@ -152,5 +182,8 @@ class Server:
             
             
     def start(self):
+        '''
+        Starts the server on the given port.
+        '''
         logger.info("Started Websocket Server")
-        self.websocket.run_forever()
+        self.websocket.run_forever()
\ No newline at end of file
